Layout class

Constructors

Layout(double left, double top, double width, double height)
Layout.clone(Layout source)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
final
left → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
final
width → double
final

Methods

areEqual(Layout v) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lerp(Layout from, Layout to, double f) → Layout