Mat2D class

Properties

hashCode → int
The hash code for this object.
no setterinherited
isIdentity → bool
no setter
mat4 → Float64List
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translation → Vec2D
no setter
values → Float32List
no setter
xDirection → Vec2D
no setter
yDirection → Vec2D
no setter

Methods

mapXY(double x, double y) → Vec2D
mul(Mat2D other) → Mat2D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator *(Vec2D v) → Vec2D
operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → double
operator []=(int index, double value) → void

Static Properties

identity → Mat2D
final

Static Methods

areEqual(Mat2D a, Mat2D b) → bool
cCopy(Mat2D o, Mat2D a) → void
compose(Mat2D m, TransformComponents result) → void
copy(Mat2D o, Mat2D f) → void
copyFromList(Mat2D o, Float32List f) → void
decompose(Mat2D m, TransformComponents result) → void
fromRotation(Mat2D o, double rad) → Mat2D
getScale(Mat2D m, Vec2D s) → void
getTranslation(Mat2D m, Vec2D t) → Vec2D
invert(Mat2D o, Mat2D a) → bool
multiply(Mat2D o, Mat2D a, Mat2D b) → Mat2D
multiplySkipIdentity(Mat2D a, Mat2D b) → Mat2D
scale(Mat2D o, Mat2D a, Vec2D v) → void
scaleByValues(Mat2D o, double x, double y) → void
setIdentity(Mat2D mat) → void
translate(Mat2D o, Mat2D a, Vec2D b) → Mat2D