ProjectionResult class

Result of projecting a point onto a segment.

Constructors

ProjectionResult(double t, Vec2D point)

Properties

hashCode → int
The hash code for this object.
no setterinherited
point → Vec2D
The actual 2d point in the same space as Segment2D.start and Segment2D.end.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
t → double
The distance factor from 0-1 along the segment starting at the Segment2D.start.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited