Segment2D class

A line segment with a discrete start and end.

Constructors

Segment2D(Vec2D start, Vec2D end)

Properties

diff → Vec2D
no setter
end → Vec2D
The ending point of this line segment.
final
hashCode → int
The hash code for this object.
no setterinherited
lengthSquared ↔ double
The squared length of this segment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Vec2D
The starting point of this line segment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
projectPoint(Vec2D point, {bool clamp = true}) → ProjectionResult
Find where the given point lies on this segment.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited