Font class abstract

Constructors

Font()

Properties

ascent → double
no setter
axes → Iterable<FontAxis>
no setter
descent → double
no setter
features → Iterable<FontTag>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

axisValue(int axisTag) → double
dispose() → void
getPath(int glyphId) → RawPath
getUiPath(int glyphId) → Path
lineHeight(double fontSize) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shape(String text, List<TextRun> runs) → TextShapeResult
toString() → String
A string representation of this object.
inherited
withOptions(Iterable<FontAxisCoord> coords, Iterable<FontFeature> features) → Font?

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Uint8List bytes) → Font?
disableFallback() → void
enableFallback() → void
initialize() → Future<FontInitStatus>
setFallbacks(List<Font> fonts) → void