GlyphLookup class

Stores the glyphId/Index representing the unicode point at i.

Constructors

GlyphLookup(List<int> indices)
GlyphLookup.fromShape(TextShapeResult shape, int codeUnitCount)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
indices → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

advanceFactor(int index, bool inv) → double
How far this codePoint index is within the glyph.
count(int index) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited