Paragraph class abstract

Constructors

Paragraph()

Properties

direction → TextDirection
no setter
hashCode → int
The hash code for this object.
no setterinherited
logicalRuns → List<GlyphRun>
no setter
runs → List<GlyphRun>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visualRuns → List<GlyphRun>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderVisually(List<GlyphRun> glyphRuns) → List<GlyphRun>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited